@@ -13,15 +13,15 @@ use POE qw(
 
 # Process Arguments
 my ($opt,$usage) = describe_options( '%c - %o',
-    ['syslog-listen|sl:s', "Address to listen for incoming syslog, default: 0.0.0.0", { default => '0.0.0.0' } ],
-    ['syslog-port|sp:i',   "TCP port to listen for incoming syslog, default 514", { default => 514 } ],
+    ['syslog-listen|sl=s', "Address to listen for incoming syslog, default: 0.0.0.0", { default => '0.0.0.0' } ],
+    ['syslog-port|sp=i',   "TCP port to listen for incoming syslog, default 514", { default => 514 } ],
     [],
-    ['eris-listen|el:s', "Address to listen for eris clients, default: 127.0.0.1", { default => '127.0.0.1' } ],
-    ['eris-port|ep:i',   "TCP port to listen for incoming syslog, default 9514", { default => 9514 } ],
+    ['eris-listen|el=s', "Address to listen for eris clients, default: 127.0.0.1", { default => '127.0.0.1' } ],
+    ['eris-port|ep=i',   "TCP port to listen for incoming syslog, default 9514", { default => 9514 } ],
     [],
-    ['graphite-host|g:s',  "Host to use to submit graphite metrics, default: disabled" ],
-    ['graphite-port|gp:i', "Port for graphite metric submission, default: 2003", {default => 2003} ],
-    ['graphite-prefix:s',  "Graphite prefix for metrics, default from POE::Component::Server::eris"],
+    ['graphite-host|g=s',  "Host to use to submit graphite metrics, default: disabled" ],
+    ['graphite-port|gp=i', "Port for graphite metric submission, default: 2003", {default => 2003} ],
+    ['graphite-prefix=s',  "Graphite prefix for metrics, default from POE::Component::Server::eris"],
     [],
     ['help',       "Show this message and exit.", { shortcircuit => 1 } ],
 );
@@ -35,7 +35,7 @@ if( $opt->help ) {
 # POE Session Initialization
 
 # Eris Server
-my $SESSION = POE::Component::Server::eris->spawn(
+my $ERIS = POE::Component::Server::eris->spawn(
 		ListenAddress	=> $opt->eris_listen,
 		ListenPort		=> $opt->eris_port,
         GraphitePort    => $opt->graphite_port,
@@ -80,7 +80,7 @@ sub client_input {
 	my ($kernel,$heap,$ses,$msg) = @_[KERNEL,HEAP,SESSION,ARG0];
 	my $sid = $ses->ID;
 
-	$kernel->post( $SESSION->{alias} => dispatch_message => $msg );
+	$kernel->post( $ERIS->{ID} => dispatch_message => $msg );
 }
 #--------------------------------------------------------------------------#
 
@@ -96,19 +96,17 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 eris-dispatch-tcp.pl - Example using POE::Component::Server::eris with a PoCo::Server::TCP Implementation
 
 =head1 VERSION
 
-version 2.5
+version 2.6
 
 =head1 AUTHOR
 
-Brad Lhotsky <brad@divsionbyzero.net>
+Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
